@@ -6,6 +6,7 @@ import concurrent.futures
 import logging
 from colorama import Fore, Back, Style
 class Weather:
+    obj=Weather()
     def hitEndpoint(city_name):
         final_url=weather_url_start+str(city_name)+weather_url_end+str(api_key)
         response=requests.post(final_url,data=city_name,headers={"Content-Type":"application/json"})
@@ -13,7 +14,7 @@ class Weather:
     def getWeather(city_name):
         #Hitting open weather map endpoint in seperate thread to achieve MultiTasking
         with concurrent.futures.ThreadPoolExecutor() as executor:
-            future = executor.submit(hitEndpoint,city_name)
+            future = executor.submit(obj.hitEndpoint,city_name)
             response= future.result()
         data=response.json()
         #Error Handling if open weather api is not success
